__title__ = 'pif.defaults'
__author__ = 'Artur Barseghyan'
__copyright__ = 'Copyright (c) 2013-2016 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'
__all__ = ('IP_CHECKERS_DIR', 'IP_CHECKER_MODULE_NAME', 'DEBUG',)

IP_CHECKERS_DIR = 'checkers'
IP_CHECKER_MODULE_NAME = 'pif_ip_checker'

DEBUG = False
